require 'web'
require 'loginpd'
require 'todopd'
require 'personpd'
require 'checkpd'

class Session < Web::Session
  attr_reader :application, :base
  def initialize
    super
    @application = $application
    @base = BaseProducer.new(self)
    @hint = 'guest' if hint.nil? || hint.empty?
  end
  def service(context)
    request(context)
    context.content = @base.to_html(context)
  end
  def login(name, password)
    @application.login.login(name, password)
    @username = name
    @hint = @username
  end
end
class BaseProducer < Web::Producer
  set_erb('base.erb')
  attr_reader :login, :todo, :person, :check
  def initialize(session)
    super(session)
    @mode = nil
    @login = LoginProducer.new(session)
    @todo = TodoProducer.new(session, session.application.todo)
    @person = PersonProducer.new(session, session.application.person)
    @check = CheckProducer.new(session, session.application.check, @todo, @person)
    hide
  end
  def hide
    @todo.hide
    @person.hide
    @check.hide
  end
  def do_hide(context, params)
    hide
  end
  def do_todo(context, params)
    @todo.browse
    @person.hide
    @check.hide
  end
  def do_person(context, params)
    @todo.hide
    @person.browse
    @check.hide
  end
  def do_debug(context, params)
    @todo.browse
    @person.browse
    @check.browse
  end
end
class Application < Web::Application
  attr_reader :login, :todo, :person, :check
  def initialize
    super(Session)
    @login = Login.new
    @todo = Todo.new
    @person = Person.new
    @check = Check.new
  end
end

$application = Application.new
if $0 == __FILE__
  require 'drb'
  DRb.start_service('druby://localhost:9161', $application)
  puts 'URI: ' + DRb.uri
  DRb.thread.join
end
